@@ -1,33 +1,12 @@
-# -*- coding: utf-8 -*-
-
-########################################################################
-#
-# License: BSD
-# Created: 2005-05-18
-# Author: Francesc Alted - faltet@pytables.org
-# Author: Ivan Vilata - ivan@selidor.net
-#
-# $Id$
-#
-########################################################################
-
 """Test module for nested types under PyTables."""
 
-from __future__ import print_function
-from __future__ import absolute_import
 import sys
 import itertools
 
-import numpy
+import numpy as np
 
-import tables as t
-from tables.utils import SizeType
+import tables as tb
 from tables.tests import common
-from tables.tests.common import unittest, test_filename
-from tables.tests.common import PyTablesTestCase as TestCase
-from tables.description import Description
-import six
-from six.moves import range
 
 minRowIndex = 10
 
@@ -45,33 +24,34 @@ minRowIndex = 10
 # Please note that some fields are explicitly ordered while others are
 # ordered alphabetically by name.
 # The declaration of the nested table:
-class Info(t.IsDescription):
+class Info(tb.IsDescription):
     _v_pos = 3
-    Name = t.StringCol(itemsize=2)
-    Value = t.ComplexCol(itemsize=16)
+    Name = tb.StringCol(itemsize=2)
+    Value = tb.ComplexCol(itemsize=16)
 
 
-class TestTDescr(t.IsDescription):
+class TestTDescr(tb.IsDescription):
     """A description that has several nested columns."""
 
-    x = t.Int32Col(dflt=0, shape=2, pos=0)  # 0
-    y = t.Float64Col(dflt=1, shape=(2, 2))
-    z = t.UInt8Col(dflt=1)
-    color = t.StringCol(itemsize=2, dflt=b" ", pos=2)
+    x = tb.Int32Col(dflt=0, shape=2, pos=0)  # 0
+    y = tb.Float64Col(dflt=1, shape=(2, 2))
+    z = tb.UInt8Col(dflt=1)
+    color = tb.StringCol(itemsize=2, dflt=b" ", pos=2)
     info = Info()
 
-    class Info(t.IsDescription):  # 1
+    class Info(tb.IsDescription):  # 1
         _v_pos = 1
-        name = t.StringCol(itemsize=2)
-        value = t.ComplexCol(itemsize=16, pos=0)  # 0
-        y2 = t.Float64Col(dflt=1, pos=1)  # 1
-        z2 = t.UInt8Col(dflt=1)
+        name = tb.StringCol(itemsize=2)
+        value = tb.ComplexCol(itemsize=16, pos=0)  # 0
+        y2 = tb.Float64Col(dflt=1, pos=1)  # 1
+        z2 = tb.UInt8Col(dflt=1)
+
+        class Info2(tb.IsDescription):
+            y3 = tb.Time64Col(dflt=1, shape=2)
+            z3 = tb.EnumCol({'r': 4, 'g': 2, 'b': 1}, 'r', 'int32', shape=2)
+            name = tb.StringCol(itemsize=2)
+            value = tb.ComplexCol(itemsize=16, shape=2)
 
-        class Info2(t.IsDescription):
-            y3 = t.Time64Col(dflt=1, shape=2)
-            z3 = t.EnumCol({'r': 4, 'g': 2, 'b': 1}, 'r', 'int32', shape=2)
-            name = t.StringCol(itemsize=2)
-            value = t.ComplexCol(itemsize=16, shape=2)
 
 # The corresponding nested array description:
 testADescr = [
@@ -80,15 +60,15 @@ testADescr = [
         ('value', 'complex128'),
         ('y2', 'float64'),
         ('Info2', [
-            ('name', 'a2'),
+            ('name', 'S2'),
             ('value', '(2,)complex128'),
             ('y3', '(2,)float64'),
             ('z3', '(2,)int32')]),
-        ('name', 'a2'),
+        ('name', 'S2'),
         ('z2', 'uint8')]),
-    ('color', 'a2'),
+    ('color', 'S2'),
     ('info', [
-        ('Name', 'a2'),
+        ('Name', 'S2'),
         ('Value', 'complex128')]),
     ('y', '(2,2)float64'),
     ('z', 'uint8')]
@@ -123,7 +103,7 @@ testABuffer = [
     ((4, 3), (7j, 7., ('oo', (7j, 5j), (7., 5.), (2, 1)),
      'OO', 9), 'dd', ('OO', 7j), ((7., 5.), (7., 5.)), 9),
 ]
-testAData = numpy.array(testABuffer, dtype=testADescr)
+testAData = np.array(testABuffer, dtype=testADescr)
 # The name of the column to be searched:
 testCondCol = 'Info/z2'
 # The name of a nested column (it can not be searched):
@@ -140,7 +120,7 @@ def areDescriptionsEqual(desc1, desc2):
 
     """
 
-    if isinstance(desc1, t.Col):
+    if isinstance(desc1, tb.Col):
         # This is a rough comparison but it suffices here.
         return (desc1.type == desc2.type
                 and desc2.dtype == desc2.dtype
@@ -165,7 +145,7 @@ def areDescriptionsEqual(desc1, desc2):
     if len(cols1) != len(cols2):
         return False
 
-    for (colName, colobj1) in six.iteritems(cols1):
+    for (colName, colobj1) in cols1.items():
         colobj2 = cols2[colName]
         if colName == '_v_pos':
             # The comparison may not be quite exhaustive!
@@ -177,7 +157,7 @@ def areDescriptionsEqual(desc1, desc2):
 
 
 # Test creating nested column descriptions
-class DescriptionTestCase(TestCase):
+class DescriptionTestCase(common.PyTablesTestCase):
     _TestTDescr = TestTDescr
     _testADescr = testADescr
     _testADescr2 = testADescr2
@@ -193,7 +173,7 @@ class DescriptionTestCase(TestCase):
     def test01_instance(self):
         """Checking attrs of an instance of a nested description."""
 
-        descr = Description(self._TestTDescr().columns)
+        descr = tb.description.Description(self._TestTDescr().columns)
         if common.verbose:
             print("Generated description:", descr._v_nested_descr)
             print("Should look like:", self._testADescr2)
@@ -202,7 +182,7 @@ class DescriptionTestCase(TestCase):
 
 
 # Test creating a nested table and opening it
-class CreateTestCase(common.TempFileMixin, TestCase):
+class CreateTestCase(common.TempFileMixin, common.PyTablesTestCase):
     _TestTDescr = TestTDescr
     _testABuffer = testABuffer
     _testAData = testAData
@@ -211,8 +191,8 @@ class CreateTestCase(common.TempFileMixin, TestCase):
         """Check that `cols` has all the accessors for `self._TestTDescr`."""
 
         # ``_desc`` is a leaf column and ``cols`` a ``Column``.
-        if isinstance(desc, t.Col):
-            return isinstance(cols, t.Column)
+        if isinstance(desc, tb.Col):
+            return isinstance(cols, tb.Column)
 
         # ``_desc`` is a description object and ``cols`` a ``Cols``.
         descColumns = desc._v_colobjects
@@ -265,7 +245,7 @@ class CreateTestCase(common.TempFileMixin, TestCase):
         tbl = self.h5file.create_table(
             '/', 'test', self._TestTDescr, title=self._getMethodName())
 
-        nrarr = numpy.array(testABuffer, dtype=tbl.description._v_nested_descr)
+        nrarr = np.array(testABuffer, dtype=tbl.description._v_nested_descr)
         self.assertTrue(common.areArraysEqual(nrarr, self._testAData),
                         "Can not create a compatible structured array.")
 
@@ -299,7 +279,7 @@ class CreateTestCase(common.TempFileMixin, TestCase):
 
 
 # Test writing data in a nested table
-class WriteTestCase(common.TempFileMixin, TestCase):
+class WriteTestCase(common.TempFileMixin, common.PyTablesTestCase):
     _TestTDescr = TestTDescr
     _testAData = testAData
     _testCondition = testCondition
@@ -473,8 +453,8 @@ class WriteTestCase(common.TempFileMixin, TestCase):
         raTable = self._testAData.copy()
         raColumn = raTable[nColumn]
         (raColumn[0], raColumn[-1]) = (raColumn[-1].copy(), raColumn[0].copy())
-        newdtype = numpy.dtype([(nColumn, raTable.dtype.fields[nColumn][0])])
-        self.assertTrue(newdtype is not None)
+        newdtype = np.dtype([(nColumn, raTable.dtype.fields[nColumn][0])])
+        self.assertIsNotNone(newdtype)
 
         # Write the resulting column and re-read the whole table.
         tbl.modify_columns(names=[nColumn], columns=raColumn)
@@ -503,14 +483,14 @@ class WriteTestCase(common.TempFileMixin, TestCase):
 
         # Get the nested column data and swap the first and last rows.
         colnames = ['x', 'color']  # Get the first two columns
-        raCols = numpy.rec.fromarrays([
+        raCols = np.rec.fromarrays([
             self._testAData['x'].copy(),
             self._testAData['color'].copy()],
-            dtype=[('x', '(2,)i4'), ('color', '1a2')])
-            # descr=tbl.description._v_nested_descr[0:2])
-            # or...
-            # names=tbl.description._v_nested_names[0:2],
-            # formats=tbl.description._v_nested_formats[0:2])
+            dtype=[('x', '(2,)i4'), ('color', 'S2')])
+        # descr=tbl.description._v_nested_descr[0:2])
+        # or...
+        # names=tbl.description._v_nested_names[0:2],
+        # formats=tbl.description._v_nested_formats[0:2])
         (raCols[0], raCols[-1]) = (raCols[-1].copy(), raCols[0].copy())
 
         # Write the resulting columns
@@ -522,9 +502,9 @@ class WriteTestCase(common.TempFileMixin, TestCase):
             tbl = self.h5file.root.test
 
         # Re-read the appropriate columns
-        raCols2 = numpy.rec.fromarrays([tbl.cols._f_col('x'),
-                                        tbl.cols._f_col('color')],
-                                       dtype=raCols.dtype)
+        raCols2 = np.rec.fromarrays([tbl.cols._f_col('x'),
+                                     tbl.cols._f_col('color')],
+                                    dtype=raCols.dtype)
         if common.verbose:
             print("Table read:", raCols2)
             print("Should look like:", raCols)
@@ -573,7 +553,7 @@ class WriteTestCase(common.TempFileMixin, TestCase):
         tbl.flush()
         coltoindex = tbl.cols._f_col(self._testCondCol)
         indexrows = coltoindex.create_index()
-        self.assertTrue(indexrows is not None)
+        self.assertIsNotNone(indexrows)
 
         if self.reopen:
             self._reopen()
@@ -594,7 +574,7 @@ class WriteTestCase(common.TempFileMixin, TestCase):
             self._testCondition, self._testCondVars(tbl))
         searchedCoords.sort()
 
-        expectedCoords = numpy.arange(0, minRowIndex * 2, 2, SizeType)
+        expectedCoords = np.arange(0, minRowIndex * 2, 2, tb.utils.SizeType)
         if common.verbose:
             print("Searched coords:", searchedCoords)
             print("Expected coords:", expectedCoords)
@@ -631,7 +611,7 @@ class WriteReopen(WriteTestCase):
     reopen = 1
 
 
-class ReadTestCase(common.TempFileMixin, TestCase):
+class ReadTestCase(common.TempFileMixin, common.PyTablesTestCase):
     _TestTDescr = TestTDescr
     _testABuffer = testABuffer
     _testAData = testAData
@@ -652,51 +632,29 @@ class ReadTestCase(common.TempFileMixin, TestCase):
             print("str(tbl)-->", str(tbl))
             print("repr(tbl)-->", repr(tbl))
 
-        self.assertEqual(str(tbl), "/test (Table(2,)) 'test00'")
+        self.assertEqual(str(tbl), f"/test (Table({np.int64(2)!r},)) {np.str_('test00')!r}")
         tblrepr = repr(tbl)
         # Remove the platform-dependent information (i.e. byteorder)
         tblrepr = "\n".join(tblrepr.split("\n")[:-2]) + "\n"
-        if sys.version_info[0] < 3:
-            template = """/test (Table(2,)) 'test00'
-  description := {
-  "x": Int32Col(shape=(2,), dflt=0, pos=0),
-  "Info": {
-    "value": ComplexCol(itemsize=16, shape=(), dflt=0j, pos=0),
-    "y2": Float64Col(shape=(), dflt=1.0, pos=1),
-    "Info2": {
-      "name": StringCol(itemsize=2, shape=(), dflt='', pos=0),
-      "value": ComplexCol(itemsize=16, shape=(2,), dflt=0j, pos=1),
-      "y3": Time64Col(shape=(2,), dflt=1.0, pos=2),
-      "z3": EnumCol(enum=Enum({%(value)s}), dflt='r', base=Int32Atom(shape=(), dflt=0), shape=(2,), pos=3)},
-    "name": StringCol(itemsize=2, shape=(), dflt='', pos=3),
-    "z2": UInt8Col(shape=(), dflt=1, pos=4)},
-  "color": StringCol(itemsize=2, shape=(), dflt=' ', pos=2),
-  "info": {
-    "Name": StringCol(itemsize=2, shape=(), dflt='', pos=0),
-    "Value": ComplexCol(itemsize=16, shape=(), dflt=0j, pos=1)},
-  "y": Float64Col(shape=(2, 2), dflt=1.0, pos=4),
-  "z": UInt8Col(shape=(), dflt=1, pos=5)}
-"""
-        else:
-            template = """/test (Table(2,)) 'test00'
-  description := {
-  "x": Int32Col(shape=(2,), dflt=0, pos=0),
-  "Info": {
-    "value": ComplexCol(itemsize=16, shape=(), dflt=0j, pos=0),
-    "y2": Float64Col(shape=(), dflt=1.0, pos=1),
-    "Info2": {
-      "name": StringCol(itemsize=2, shape=(), dflt=b'', pos=0),
-      "value": ComplexCol(itemsize=16, shape=(2,), dflt=0j, pos=1),
-      "y3": Time64Col(shape=(2,), dflt=1.0, pos=2),
-      "z3": EnumCol(enum=Enum({%(value)s}), dflt='%(default)s', base=Int32Atom(shape=(), dflt=0), shape=(2,), pos=3)},
-    "name": StringCol(itemsize=2, shape=(), dflt=b'', pos=3),
-    "z2": UInt8Col(shape=(), dflt=1, pos=4)},
-  "color": StringCol(itemsize=2, shape=(), dflt=b' ', pos=2),
-  "info": {
-    "Name": StringCol(itemsize=2, shape=(), dflt=b'', pos=0),
-    "Value": ComplexCol(itemsize=16, shape=(), dflt=0j, pos=1)},
-  "y": Float64Col(shape=(2, 2), dflt=1.0, pos=4),
-  "z": UInt8Col(shape=(), dflt=1, pos=5)}
+        template = f"""/test (Table({np.int64(2)!r},)) {np.str_('test00')!r}
+  description := {{
+  "x": Int32Col(shape=({np.int64(2)!r},), dflt={np.int32(0)!r}, pos=0),
+  "Info": {{
+    "value": ComplexCol(itemsize=16, shape=(), dflt={np.complex128(0j)!r}, pos=0),
+    "y2": Float64Col(shape=(), dflt={np.float64(1.0)!r}, pos=1),
+    "Info2": {{
+      "name": StringCol(itemsize=2, shape=(), dflt={np.bytes_(b'')!r}, pos=0),
+      "value": ComplexCol(itemsize=16, shape=({np.int64(2)!r},), dflt={np.complex128(0j)!r}, pos=1),
+      "y3": Time64Col(shape=({np.int64(2)!r},), dflt={np.float64(1.0)!r}, pos=2),
+      "z3": EnumCol(enum=Enum({{%(value)s}}), dflt='%(default)s', base=Int32Atom(shape=(), dflt={np.int32(0)!r}), shape=({np.int64(2)!r},), pos=3)}},
+    "name": StringCol(itemsize=2, shape=(), dflt={np.bytes_(b'')!r}, pos=3),
+    "z2": UInt8Col(shape=(), dflt={np.uint8(1)!r}, pos=4)}},
+  "color": StringCol(itemsize=2, shape=(), dflt={np.bytes_(b' ')!r}, pos=2),
+  "info": {{
+    "Name": StringCol(itemsize=2, shape=(), dflt={np.bytes_(b'')!r}, pos=0),
+    "Value": ComplexCol(itemsize=16, shape=(), dflt={np.complex128(0j)!r}, pos=1)}},
+  "y": Float64Col(shape=({np.int64(2)!r}, {np.int64(2)!r}), dflt={np.float64(1.0)!r}, pos=4),
+  "z": UInt8Col(shape=(), dflt={np.uint8(1)!r}, pos=5)}}
 """
 
         # The problem here is that the order in which items are stored in a
@@ -716,14 +674,16 @@ class ReadTestCase(common.TempFileMixin, TestCase):
         # of the possible default values.
         enums = [
             ', '.join(items) for items in itertools.permutations(
-                ("'r': 4", "'b': 1", "'g': 2"))
+                (f"'r': {np.int32(4)!r}", f"'b': {np.int32(1)!r}", f"'g': {np.int32(2)!r}")
+                if self.reopen
+                else ("'r': 4", "'b': 1", "'g': 2"))
         ]
         defaults = ('r', 'b', 'g')
         values = [
             template % {'value': v, 'default': d}
             for v, d in itertools.product(enums, defaults)
         ]
-        self.assertTrue(tblrepr in values)
+        self.assertIn(tblrepr, values)
 
     def test00b_repr(self):
         """Checking representation of a root Column."""
@@ -741,9 +701,9 @@ class ReadTestCase(common.TempFileMixin, TestCase):
             print("repr(tbl.cols.y)-->'%s'" % repr(tbl.cols.y))
 
         self.assertEqual(str(tbl.cols.y),
-                         "/test.cols.y (Column(2, 2, 2), float64, idx=None)")
+                         f"/test.cols.y (Column({np.int64(2)!r}, 2, 2), float64, idx=None)")
         self.assertEqual(repr(tbl.cols.y),
-                         "/test.cols.y (Column(2, 2, 2), float64, idx=None)")
+                         f"/test.cols.y (Column({np.int64(2)!r}, 2, 2), float64, idx=None)")
 
     def test00c_repr(self):
         """Checking representation of a nested Column."""
@@ -761,9 +721,9 @@ class ReadTestCase(common.TempFileMixin, TestCase):
             print("repr(tbl.cols.Info.z2)-->'%s'" % repr(tbl.cols.Info.z2))
 
         self.assertEqual(str(tbl.cols.Info.z2),
-                         "/test.cols.Info.z2 (Column(2,), uint8, idx=None)")
+                         f"/test.cols.Info.z2 (Column({np.int64(2)!r},), uint8, idx=None)")
         self.assertEqual(repr(tbl.cols.Info.z2),
-                         "/test.cols.Info.z2 (Column(2,), uint8, idx=None)")
+                         f"/test.cols.Info.z2 (Column({np.int64(2)!r},), uint8, idx=None)")
 
     def test01_read(self):
         """Checking Table.read with subgroups with a range index with step."""
@@ -776,8 +736,8 @@ class ReadTestCase(common.TempFileMixin, TestCase):
             self._reopen()
             tbl = self.h5file.root.test
 
-        nrarr = numpy.rec.array(testABuffer,
-                                dtype=tbl.description._v_nested_descr)
+        nrarr = np.rec.array(testABuffer,
+                             dtype=tbl.description._v_nested_descr)
         tblcols = tbl.read(start=0, step=2, field='Info')
         nrarrcols = nrarr['Info'][0::2]
         if common.verbose:
@@ -795,13 +755,13 @@ class ReadTestCase(common.TempFileMixin, TestCase):
             self._reopen()
             tbl = self.h5file.root.test
 
-        nrarr = numpy.rec.array(testABuffer,
-                                dtype=tbl.description._v_nested_descr)
+        nrarr = np.rec.array(testABuffer,
+                             dtype=tbl.description._v_nested_descr)
         # When reading an entire nested column, the output array must contain
         # all fields in the table.  The output buffer will contain the contents
         # of all fields.  The selected column alone will be returned from the
         # method call.
-        all_cols = numpy.empty(1, tbl.dtype)
+        all_cols = np.empty(1, tbl.dtype)
         tblcols = tbl.read(start=0, step=2, field='Info', out=all_cols)
         nrarrcols = nrarr['Info'][0::2]
         if common.verbose:
@@ -824,8 +784,8 @@ class ReadTestCase(common.TempFileMixin, TestCase):
             tbl = self.h5file.root.test
 
         tblcols = tbl.read(start=0, step=2, field='Info/value')
-        nrarr = numpy.rec.array(testABuffer,
-                                dtype=tbl.description._v_nested_descr)
+        nrarr = np.rec.array(testABuffer,
+                             dtype=tbl.description._v_nested_descr)
         nrarrcols = nrarr['Info']['value'][0::2]
         self.assertTrue(common.areArraysEqual(nrarrcols, tblcols),
                         "Original array are retrieved doesn't match.")
@@ -841,10 +801,10 @@ class ReadTestCase(common.TempFileMixin, TestCase):
             self._reopen()
             tbl = self.h5file.root.test
 
-        tblcols = numpy.empty(1, dtype='c16')
+        tblcols = np.empty(1, dtype='c16')
         tbl.read(start=0, step=2, field='Info/value', out=tblcols)
-        nrarr = numpy.rec.array(testABuffer,
-                                dtype=tbl.description._v_nested_descr)
+        nrarr = np.rec.array(testABuffer,
+                             dtype=tbl.description._v_nested_descr)
         nrarrcols = nrarr['Info']['value'][0::2]
         self.assertTrue(common.areArraysEqual(nrarrcols, tblcols),
                         "Original array are retrieved doesn't match.")
@@ -859,7 +819,7 @@ class ReadReopen(ReadTestCase):
 
 
 # Checking the Table.Cols accessor
-class ColsTestCase(common.TempFileMixin, TestCase):
+class ColsTestCase(common.TempFileMixin, common.PyTablesTestCase):
     _TestTDescr = TestTDescr
     _testABuffer = testABuffer
     _testAData = testAData
@@ -893,14 +853,14 @@ class ColsTestCase(common.TempFileMixin, TestCase):
                              )
         except AssertionError:
             self.assertEqual(repr(tbl.cols),
-                             """/test.cols (Cols), 6 columns
-  x (Column(0, 2), ('%s', (2,)))
+                             f"""/test.cols (Cols), 6 columns
+  x (Column({np.int64(0)!r}, 2), ('{np.int32(0).dtype.str}', (2,)))
   Info (Cols(), Description)
-  color (Column(0,), |S2)
+  color (Column({np.int64(0)!r},), |S2)
   info (Cols(), Description)
-  y (Column(0, 2, 2), ('%s', (2, 2)))
-  z (Column(0,), uint8)
-""" % (numpy.int32(0).dtype.str, numpy.float64(0).dtype.str))
+  y (Column({np.int64(0)!r}, 2, 2), ('{np.float64(0).dtype.str}', (2, 2)))
+  z (Column({np.int64(0)!r},), uint8)
+""")
 
     def test00b_repr(self):
         """Checking string representation of nested Cols."""
@@ -919,12 +879,12 @@ class ColsTestCase(common.TempFileMixin, TestCase):
         self.assertEqual(str(
             tbl.cols.Info), "/test.cols.Info (Cols), 5 columns")
         self.assertEqual(repr(tbl.cols.Info),
-                         """/test.cols.Info (Cols), 5 columns
-  value (Column(0,), complex128)
-  y2 (Column(0,), float64)
+                         f"""/test.cols.Info (Cols), 5 columns
+  value (Column({np.int64(0)!r},), complex128)
+  y2 (Column({np.int64(0)!r},), float64)
   Info2 (Cols(), Description)
-  name (Column(0,), |S2)
-  z2 (Column(0,), uint8)
+  name (Column({np.int64(0)!r},), |S2)
+  z2 (Column({np.int64(0)!r},), uint8)
 """)
 
     def test01a_f_col(self):
@@ -1014,7 +974,7 @@ class ColsTestCase(common.TempFileMixin, TestCase):
             self._reopen()
             tbl = self.h5file.root.test
 
-        nrarr = numpy.array(testABuffer, dtype=tbl.description._v_nested_descr)
+        nrarr = np.array(testABuffer, dtype=tbl.description._v_nested_descr)
         tblcols = tbl.cols[1]
         nrarrcols = nrarr[1]
         if common.verbose:
@@ -1034,7 +994,7 @@ class ColsTestCase(common.TempFileMixin, TestCase):
             self._reopen()
             tbl = self.h5file.root.test
 
-        nrarr = numpy.array(testABuffer, dtype=tbl.description._v_nested_descr)
+        nrarr = np.array(testABuffer, dtype=tbl.description._v_nested_descr)
         tblcols = tbl.cols[0:2]
         nrarrcols = nrarr[0:2]
         if common.verbose:
@@ -1054,7 +1014,7 @@ class ColsTestCase(common.TempFileMixin, TestCase):
             self._reopen()
             tbl = self.h5file.root.test
 
-        nrarr = numpy.array(testABuffer, dtype=tbl.description._v_nested_descr)
+        nrarr = np.array(testABuffer, dtype=tbl.description._v_nested_descr)
         tblcols = tbl.cols[0::2]
         nrarrcols = nrarr[0::2]
         if common.verbose:
@@ -1074,7 +1034,7 @@ class ColsTestCase(common.TempFileMixin, TestCase):
             self._reopen()
             tbl = self.h5file.root.test
 
-        nrarr = numpy.array(testABuffer, dtype=tbl.description._v_nested_descr)
+        nrarr = np.array(testABuffer, dtype=tbl.description._v_nested_descr)
         tblcols = tbl.cols._f_col('Info')[1]
         nrarrcols = nrarr['Info'][1]
         if common.verbose:
@@ -1094,7 +1054,7 @@ class ColsTestCase(common.TempFileMixin, TestCase):
             self._reopen()
             tbl = self.h5file.root.test
 
-        nrarr = numpy.array(testABuffer, dtype=tbl.description._v_nested_descr)
+        nrarr = np.array(testABuffer, dtype=tbl.description._v_nested_descr)
         tblcols = tbl.cols._f_col('Info')[0:2]
         nrarrcols = nrarr['Info'][0:2]
         if common.verbose:
@@ -1115,7 +1075,7 @@ class ColsTestCase(common.TempFileMixin, TestCase):
             self._reopen()
             tbl = self.h5file.root.test
 
-        nrarr = numpy.array(testABuffer, dtype=tbl.description._v_nested_descr)
+        nrarr = np.array(testABuffer, dtype=tbl.description._v_nested_descr)
         tblcols = tbl.cols._f_col('Info')[0::2]
         nrarrcols = nrarr['Info'][0::2]
         if common.verbose:
@@ -1135,7 +1095,7 @@ class ColsTestCase(common.TempFileMixin, TestCase):
             self._reopen()
             tbl = self.h5file.root.test
 
-        nrarr = numpy.array(testABuffer, dtype=tbl.description._v_nested_descr)
+        nrarr = np.array(testABuffer, dtype=tbl.description._v_nested_descr)
         tblcols = tbl.cols._f_col('Info/value')[1]
         nrarrcols = nrarr['Info']['value'][1]
         if common.verbose:
@@ -1155,7 +1115,7 @@ class ColsTestCase(common.TempFileMixin, TestCase):
             self._reopen()
             tbl = self.h5file.root.test
 
-        nrarr = numpy.array(testABuffer, dtype=tbl.description._v_nested_descr)
+        nrarr = np.array(testABuffer, dtype=tbl.description._v_nested_descr)
         tblcols = tbl.cols._f_col('Info/value')[0:2]
         nrarrcols = nrarr['Info']['value'][0:2]
         if common.verbose:
@@ -1176,7 +1136,7 @@ class ColsTestCase(common.TempFileMixin, TestCase):
             self._reopen()
             tbl = self.h5file.root.test
 
-        nrarr = numpy.array(testABuffer, dtype=tbl.description._v_nested_descr)
+        nrarr = np.array(testABuffer, dtype=tbl.description._v_nested_descr)
         tblcols = tbl.cols._f_col('Info/value')[0::2]
         nrarrcols = nrarr['Info']['value'][0::2]
         if common.verbose:
@@ -1194,7 +1154,7 @@ class ColsTestCase(common.TempFileMixin, TestCase):
             self._reopen()
             tbl = self.h5file.root.test
 
-        nrarr = numpy.array(testABuffer, dtype=tbl.description._v_nested_descr)
+        nrarr = np.array(testABuffer, dtype=tbl.description._v_nested_descr)
         row_num = 0
         for item in tbl.cols.Info.value:
             self.assertEqual(item, nrarr['Info']['value'][row_num])
@@ -1210,28 +1170,29 @@ class ColsReopen(ColsTestCase):
     reopen = 1
 
 
-class Nested(t.IsDescription):
-    uid = t.IntCol(pos=1)
-    value = t.FloatCol(pos=2)
+class Nested(tb.IsDescription):
+    uid = tb.IntCol(pos=1)
+    value = tb.FloatCol(pos=2)
 
 
-class A_Candidate(t.IsDescription):
+class A_Candidate(tb.IsDescription):
     nested1 = Nested()
     nested2 = Nested()
 
 
-class B_Candidate(t.IsDescription):
+class B_Candidate(tb.IsDescription):
     nested1 = Nested
     nested2 = Nested
 
 
-class C_Candidate(t.IsDescription):
+class C_Candidate(tb.IsDescription):
     nested1 = Nested()
     nested2 = Nested
 
+
 Dnested = {
-    'uid': t.IntCol(pos=1),
-    'value': t.FloatCol(pos=2),
+    'uid': tb.IntCol(pos=1),
+    'value': tb.FloatCol(pos=2),
 }
 
 D_Candidate = {
@@ -1252,7 +1213,7 @@ F_Candidate = {
 # Checking several nested columns declared in the same way
 
 
-class SameNestedTestCase(common.TempFileMixin, TestCase):
+class SameNestedTestCase(common.TempFileMixin, common.PyTablesTestCase):
     correct_names = [
         '',  # The root of columns
         'nested1', 'nested1/uid', 'nested1/value',
@@ -1372,8 +1333,8 @@ class SameNestedTestCase(common.TempFileMixin, TestCase):
 
         desc = {
             'nested': {
-                'i1': t.Int32Col(),
-                'i2': t.Int32Col()
+                'i1': tb.Int32Col(),
+                'i2': tb.Int32Col()
             }
         }
 
@@ -1424,8 +1385,8 @@ class SameNestedTestCase(common.TempFileMixin, TestCase):
             'nested1': {
                 'nested2': {
                     'nested3': {
-                        'i1': t.Int32Col(),
-                        'i2': t.Int32Col()
+                        'i1': tb.Int32Col(),
+                        'i2': tb.Int32Col()
                     }
                 }
             }
@@ -1479,14 +1440,14 @@ class SameNestedReopen(SameNestedTestCase):
     reopen = 1
 
 
-class NestedTypesWithGaps(common.TestFileMixin, TestCase):
-    h5fname = test_filename('nested-type-with-gaps.h5')
+class NestedTypesWithGaps(common.TestFileMixin, common.PyTablesTestCase):
+    h5fname = common.test_filename('nested-type-with-gaps.h5')
 
-    correct_descr = """{
-  "float": Float32Col(shape=(), dflt=0.0, pos=0),
-  "compound": {
-    "char": Int8Col(shape=(), dflt=0, pos=0),
-    "double": Float64Col(shape=(), dflt=0.0, pos=1)}}"""
+    correct_descr = f"""{{
+  "float": Float32Col(shape=(), dflt={np.float32(0.0)!r}, pos=0),
+  "compound": {{
+    "char": Int8Col(shape=(), dflt={np.int8(0)!r}, pos=0),
+    "double": Float64Col(shape=(), dflt={np.float64(0.0)!r}, pos=1)}}}}"""
 
     def test01(self):
         """Opening a table with nested types with gaps."""
@@ -1510,22 +1471,22 @@ class NestedTypesWithGaps(common.TestFileMixin, TestCase):
 def suite():
     """Return a test suite consisting of all the test cases in the module."""
 
-    theSuite = unittest.TestSuite()
+    theSuite = common.unittest.TestSuite()
     niter = 1
     # common.heavy = 1  # uncomment this only for testing purposes
 
     for i in range(niter):
-        theSuite.addTest(unittest.makeSuite(DescriptionTestCase))
-        theSuite.addTest(unittest.makeSuite(CreateTestCase))
-        theSuite.addTest(unittest.makeSuite(WriteNoReopen))
-        theSuite.addTest(unittest.makeSuite(WriteReopen))
-        theSuite.addTest(unittest.makeSuite(ColsNoReopen))
-        theSuite.addTest(unittest.makeSuite(ColsReopen))
-        theSuite.addTest(unittest.makeSuite(ReadNoReopen))
-        theSuite.addTest(unittest.makeSuite(ReadReopen))
-        theSuite.addTest(unittest.makeSuite(SameNestedNoReopen))
-        theSuite.addTest(unittest.makeSuite(SameNestedReopen))
-        theSuite.addTest(unittest.makeSuite(NestedTypesWithGaps))
+        theSuite.addTest(common.unittest.makeSuite(DescriptionTestCase))
+        theSuite.addTest(common.unittest.makeSuite(CreateTestCase))
+        theSuite.addTest(common.unittest.makeSuite(WriteNoReopen))
+        theSuite.addTest(common.unittest.makeSuite(WriteReopen))
+        theSuite.addTest(common.unittest.makeSuite(ColsNoReopen))
+        theSuite.addTest(common.unittest.makeSuite(ColsReopen))
+        theSuite.addTest(common.unittest.makeSuite(ReadNoReopen))
+        theSuite.addTest(common.unittest.makeSuite(ReadReopen))
+        theSuite.addTest(common.unittest.makeSuite(SameNestedNoReopen))
+        theSuite.addTest(common.unittest.makeSuite(SameNestedReopen))
+        theSuite.addTest(common.unittest.makeSuite(NestedTypesWithGaps))
 
     return theSuite
 
@@ -1533,12 +1494,4 @@ def suite():
 if __name__ == '__main__':
     common.parse_argv(sys.argv)
     common.print_versions()
-    unittest.main(defaultTest='suite')
-
-
-## Local Variables:
-## mode: python
-## py-indent-offset: 4
-## tab-width: 4
-## fill-column: 72
-## End:
+    common.unittest.main(defaultTest='suite')
